[Zope3-checkins] CVS: Zope3/src/zope/app/fssync - committer.py:1.14

Steve Alexander steve@cat-box.net
Fri, 13 Jun 2003 13:41:48 -0400


Update of /cvs-repository/Zope3/src/zope/app/fssync
In directory cvs.zope.org:/tmp/cvs-serv28622/src/zope/app/fssync

Modified Files:
	committer.py 
Log Message:
Removed the @@object_name view, as used in some page templates, and
the ObjectName view and adapter also.
Extended IPhysicallyLocatable with a getName method.
Renamed the convenience function objectName to getName.

If you have page templates that use @@object_name, then you can replace it
with zope:name.



=== Zope3/src/zope/app/fssync/committer.py 1.13 => 1.14 ===
--- Zope3/src/zope/app/fssync/committer.py:1.13	Tue Jun 10 18:02:36 2003
+++ Zope3/src/zope/app/fssync/committer.py	Fri Jun 13 13:41:18 2003
@@ -33,7 +33,7 @@
 from zope.app.context import ContextWrapper
 from zope.app.interfaces.container import IContainer, IZopeContainer
 from zope.app.fssync.classes import Default
-from zope.app.traversing import getPath, traverseName, objectName
+from zope.app.traversing import getPath, traverseName, getName
 from zope.app.interfaces.file import IFileFactory, IDirectoryFactory
 from zope.app.event import publish
 from zope.app.event.objectevent import ObjectCreatedEvent
@@ -307,9 +307,9 @@
                         adapter.setBody(newdata)
                     # Now publish an event, but not for annotations or
                     # extras.  To know which case we have, see if
                     # objectName() works.  XXX This is a hack.
                     try:
-                        objectName(obj)
+                        getName(obj)
                     except:
                         pass
                     else:
@@ -307,9 +307,9 @@
                     # Now publish an event, but not for annotations or
                     # extras.  To know which case we have, see if
-                    # objectName() works.  XXX This is a hack.
+                    # getName() works.  XXX This is a hack.
                     try: